@@ -9,7 +9,7 @@ import glob
 import time
 
 
-__version__ = '0.0.11'
+__version__ = '0.0.14'
 
 samples_s3_folder = 'pypi_samples'
 inference_samples_s3_folder = 'pypi_toinfer'
@@ -116,7 +116,7 @@ class client():
         }
                 
         # Create the event 
-        resp = requests.post(event_manager_endpoint + '/create_event', json = payload)
+        resp = requests.post(event_manager_endpoint + '/event', json = payload)
         
         resp_json = json.loads(resp.content)
         
